#
# spec file for package python-geoip2
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-geoip2
Version:        4.8.0
Release:        1.1
Summary:        MaxMind GeoIP2 Python API
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/maxmind/GeoIP2-python
Source:         https://files.pythonhosted.org/packages/source/g/geoip2/geoip2-%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module aiohttp >= 3.6.2}
BuildRequires:  %{python_module maxminddb >= 2.3.0}
BuildRequires:  %{python_module mocket >= 3.11.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-magic >= 0.4.18}
BuildRequires:  %{python_module requests >= 2.14.0}
# /SECTION
Requires:       python-aiohttp >= 3.6.2
Requires:       python-maxminddb >= 2.0.0
Requires:       python-requests >= 2.14.0
Requires:       python-setuptools
BuildArch:      noarch
%python_subpackages

%description
This package provides an API for the GeoIP2 web services and databases.
The API also works with MaxMind's free GeoLite2 databases.

%prep
%setup -q -n geoip2-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
rm -v tests/webservice_test.py
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst HISTORY.rst
%{python_sitelib}/geoip2
%{python_sitelib}/geoip2-%{version}*-info

%changelog
* Sun Jan 12 2025 Sebastian Wagner <sebix@sebix.at>
- update to version 4.8.0:
  - The ``is_anycast`` attribute was added to ``geoip2.record.Traits``.
  This returns ``True`` if the IP address belongs to an
  `anycast network <https://en.wikipedia.org/wiki/Anycast>`_.
  This is available for the GeoIP2 Country, City Plus, and Insights web services
  and the GeoIP2 Country, City, and Enterprise databases.
* Sun Nov 26 2023 Dirk Müller <dmueller@suse.com>
- update to 4.7.0:
  * drop support for python 3.6
  - drop
    0001-Removing-unused-urllib3-dependency-loosening-request.patch
    (upstream)
* Fri Jun  9 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Feb 15 2023 Dirk Müller <dmueller@suse.com>
- fix tests on python 3.8 as well with newer python-mocket by skipping
  the tests/test_webservice which need porting to new python-mocket
* Mon Jan 23 2023 Daniel Garcia <daniel.garcia@suse.com>
- Disable broken tests for python 3.11. python-mocket currently does not work
  with python 3.11, so we should disable tests that uses it until it's
  supported.
  See these issues:
  gh#maxmind/GeoIP2-python@3b0dbb1eb990
  gh#mindflayer/python-mocket#181
  gh#benoitc/http-parser#95
* Mon Jul  4 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 4.6.0:
  - The AddressNotFoundError class now has an ip_address attribute
    with the lookup address and network property for the empty network
    in the database containing the IP address. These are only available
    when using a database, not the web service.
- Rebase 0001-Removing-unused-urllib3-dependency-loosening-request.patch
* Thu Nov 18 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 4.5.0:
  - Support for mobile country code (MCC) and mobile network codes (MNC) was
  added for the GeoIP2 ISP and Enterprise databases as well as the GeoIP2
  City and Insights web services. ``mobile_country_code`` and
  ``mobile_network_code`` attributes were added to ``geoip2.model.ISP``
  for the GeoIP2 ISP database and ``geoip2.record.Traits`` for the
  Enterprise database and the GeoIP2 City and Insights web services.
  We expect this data to be available by late January, 2022.
* Fri Sep 24 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 4.4.0:
  - The public API on ``geoip2.database`` is now explicitly defined by
  setting ``__all__``.
  - The return type of the ``metadata()`` method on ``Reader`` is now
  ``maxminddb.reader.Metadata`` rather than a union type.
- update to version 4.3.0:
  - Previously, the ``py.typed`` file was not being added to the source
  distribution. It is now explicitly specified in the manifest.
  - The type hints for the database file in the ``Reader`` constructor have
  been expanded to match those specified by ``maxmindb.open_database``. In
  particular, ``os.PathLike`` and ``IO`` have been added.
  - Corrected the type hint for the ``metadata()`` method on ``Reader``. It
  will return a ``maxminddb.extension.Metadata`` if the C extension is being
  used.
* Tue Jul 13 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add patch to remove urllib3 and relax requests dependencies
  + 0001-Removing-unused-urllib3-dependency-loosening-request.patch
- Update BuildRequires and Requires from requirements.txt and setup.py
* Fri May 14 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 4.2.0:
  - You may now set a proxy to use when making web service requests by passing
  the ``proxy`` parameter to the ``AsyncClient`` or ``Client`` constructor.
* Thu Dec 10 2020 Benjamin Greiner <code@bnavigator.de>
- replace deprecated setup.py test call by pyunittest macro so that
  pip does not try to download stuff
* Wed Nov  4 2020 Paolo Stivanin <info@paolostivanin.com>
- update to version 4.1.0:
  * Added the is_residential_proxy attribute to geoip2.model.AnonymousIP
    and geoip2.record.Traits.
  * HTTPError now provides the decoded response content in the
    decoded_content attribute.
* Tue Jul 28 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 4.0.2:
  - Added ``py.typed`` file per PEP 561. Reported by Árni Már Jónsson.
* Thu Jul 23 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 4.0.1:
  - Re-release to fix bad reStructuredText in ``README.md``. No substantive
    changes.
- update to version 4.0.0:
  - IMPORTANT: Python 2.7 and 3.5 support has been dropped. Python 3.6 or greater
    is required.
  - Asyncio support has been added for web service requests. To make async
    requests, use ``geoip.webservice.AsyncClient``.
  - ``geoip.webservice.Client`` now provides a ``close()`` method and associated
    context managers to be used in ``with`` statements.
  - Type hints have been added.
  - The attributes ``postal_code`` and ``postal_confidence`` have been removed
    from ``geoip2.record.Location``. These would previously always be ``None``.
  - ``user_id`` is no longer supported as a named argument for the constructor
    on ``geoip2.webservice.Client``. Use ``account_id`` or a positional
    parameter instead.
  - For both ``Client`` and ``AsyncClient`` requests, the default timeout is
    now 60 seconds.
* Thu Apr 16 2020 Marcus Rueckert <mrueckert@suse.de>
- match buildrequires to requirements.txt
* Wed Mar  4 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.0.0
  * BREAKING CHANGE: The geoip2.record.* classes have been refactored to
    improve performance. This refactoring may break classes that inherit from
    them. The public API should otherwise be compatible.
  * The network attribute was added to geoip2.record.Traits,
    geoip2.model.AnonymousIP, geoip2.model.ASN,
    geoip2.model.ConnectionType, geoip2.model.Domain,
    and geoip2.model.ISP. This is an ipaddress.IPv4Network or an
    ipaddress.IPv6Network. This is the largest network where all of the
    fields besides ip_address have the same value. GitHub #79.
  * Python 3.3 and 3.4 are no longer supported.
  * Updated documentation of anonymizer attributes - is_anonymous_vpn and
    is_hosting_provider - to be more descriptive.
  * Added support for the user_count trait for the GeoIP2 Precision webservice.
  * Added the static_ip_score attribute to geoip2.record.Traits for
  * GeoIP2 Precision Insights. This is a float which indicates how static or dynamic
    an IP address is.
* Mon Mar 11 2019 John Vandenberg <jayvdb@gmail.com>
- Fix minimum build dependency of maxminddb
- Fix fdupes
- Use more useful GitHub repo as URL
- Add HISTORY.rst to %%doc
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun May 27 2018 sebix+novell.com@sebix.at
- update to version 2.9.0:
  * You may now pass in the database via a file descriptor rather than a file
  name when creating a new ``geoip2.database.Reader`` object using ``MODE_FD``.
  This will read the database from the file descriptor into memory. Pull
  request by nkinkade. GitHub #53.
* Wed May  2 2018 tchvatal@suse.com
- Use license macro for license
* Thu Apr 12 2018 sebix+novell.com@sebix.at
- update to version 2.8.0:
  * Renamed user ID to account ID in the code and added support for the new
  ``ACCOUNT_ID_REQUIRED`` AND ``ACCOUNT_ID_UNKNOWN`` error codes.
- update to version 2.7.0:
  * The ``is_in_european_union`` attribute was added to
  ``geoip2.record.Country`` and ``geoip2.record.RepresentedCountry``. This
  attribute is ``True`` if the country is a member state of the European
  Union.
* Sat Mar  3 2018 arun@gmx.de
- specfile:
  * update copyright year
  * don't use python_module for Requires
* Fri Oct 27 2017 sebix+novell.com@sebix.at
- update to version 2.6.0:
  * The following new anonymizer attributes were added to ``geoip2.record.Traits``
  for use with GeoIP2 Precision Insights: ``is_anonymous``,
  ``is_anonymous_vpn``, ``is_hosting_provider``, ``is_public_proxy``, and
  ``is_tor_exit_node``.
* Thu May 25 2017 sebix+novell.com@sebix.at
- initial package
